#ifdef HAVE_CONFIG_H
  #include "elementary_config.h"
#endif

#include "elm_priv.h"

#include "efl_access_window.eo.c"
